excel_pal: Excel 97 ugly color palettes (discrete)

View source: R/excel.R

excel_palR Documentation

Excel 97 ugly color palettes (discrete)

Description

The color palettes used in Microsoft Excel 97 (and up until Excel 2007). Use this for that classic ugly look and feel. For ironic purposes only. 3D bars and pies not included. Please never use this color palette.

Usage

excel_pal(line = TRUE)

Arguments

line

If TRUE, use the palette for lines and points. Otherwise, use the palette for area.

Value

A palette function. It takes the number of colours n and returns a character vector of n hex colours, and can be used as the palette argument of discrete_scale().

See Also

Other colour excel: excel_new_pal(), scale_colour_excel_new(), scale_fill_excel()

Examples

library("scales")

show_col(excel_pal()(7))
show_col(excel_pal(line = FALSE)(7))

ggthemes documentation built on Oct. 4, 2026, 1:06 a.m.