fivethirtyeight_pal: FiveThirtyEight color palette

View source: R/fivethirtyeight.R

fivethirtyeight_palR Documentation

FiveThirtyEight color palette

Description

The standard three-color FiveThirtyEight palette for line plots comprises blue, red, and green.

Usage

fivethirtyeight_pal()

Value

A palette function. It takes the number of colours n and returns a character vector of n hex colours, and can be used as the palette argument of discrete_scale().

See Also

Other colour fivethirtyeight: scale_colour_fivethirtyeight()

Examples

library("scales")

show_col(fivethirtyeight_pal()(3))

ggthemes documentation built on Oct. 4, 2026, 1:06 a.m.