Skip to contents

Color palettes from Google Docs. This palette includes 20 colors.

Usage

gdocs_pal()

Value

A palette function. It takes the number of colors n and returns a character vector of n hex colors, and can be used as the palette argument of ggplot2::discrete_scale().

See also

Other color gdocs: scale_fill_gdocs()

Examples

library("scales")

show_col(gdocs_pal()(24))