| numbers_pal | R Documentation |
Color palettes used by charts in Apple Numbers. Each palette provides the six series colors that Numbers assigns to a chart's data series, in order.
numbers_pal(palette = "Classic")
palette |
Palette name. One of
\Sexpr[results=rd]{ggthemes:::rd_optlist(names(ggthemes::ggthemes_data$numbers))}.
The default, |
A palette function. It takes the number of colours n and returns a character vector of n
hex colours, and can be used as the palette argument of discrete_scale().
Other colour numbers:
scale_fill_numbers()
library("scales")
show_col(numbers_pal()(6))
show_col(numbers_pal("Spectrum")(6))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.