palette_pander: Color palette from the pander package

View source: R/pander.R

palette_panderR Documentation

Color palette from the pander package

Description

The pander ships with a default colorblind and printer-friendly color palette borrowed from ⁠https://jfly.iam.u-tokyo.ac.jp/color/⁠.

Usage

palette_pander(n, random_order = FALSE)

Arguments

n

number of colors. This palette supports up to eight colors.

random_order

if the palette should be reordered randomly before rendering each plot to get colorful images

Value

A character vector of n hex colours, recycled if n exceeds the number of colours available. Unlike the other *_pal() functions, this is itself the palette function.

See Also

Other colour pander: scale_color_pander()

Examples

palette_pander(8)
# the same colors in a random order
palette_pander(8, random_order = TRUE)

ggthemes documentation built on Oct. 4, 2026, 1:06 a.m.