scale_shape_few: Scales for shapes from "Show Me the Numbers"

View source: R/few.R

scale_shape_fewR Documentation

Scales for shapes from "Show Me the Numbers"

Description

scale_shape_few() maps discrete variables to up to five easily discernible shapes. It is based on the shape palette suggested in Few (2012).

Usage

scale_shape_few(...)

Arguments

...

Common discrete_scale() parameters.

Value

A ggplot2 scale object.

References

Few, S. (2012) Show Me the Numbers: Designing Tables and Graphs to Enlighten, Analytics Press, p. 208.

See Also

scale_shape_few() for the shape palette that this scale uses.

Examples

library("ggplot2")

ggplot(mtcars, aes(x = wt, y = mpg, shape = factor(gear))) +
  geom_point(size = 3) +
  scale_shape_few()

ggthemes documentation built on Oct. 4, 2026, 1:06 a.m.