Skip to contents

Qualitative color palette based on Ethan Schoonover's Solarized palette, https://ethanschoonover.com/solarized/. This palette supports up to seven values.

Usage

solarized_pal(accent = "blue")

Arguments

accent

A string, the name of the starting color.

Value

A palette function. It takes the number of colors n and returns a character vector of n hex colors, and can be used as the palette argument of ggplot2::discrete_scale().

Note

For a given starting color and number of colors in the palette, the other colors are the combination of colors that maximizes the total Euclidean distance between colors in Lab space.

See also

Other color solarized: scale_fill_solarized()

Examples

library("scales")

show_col(solarized_pal()(2))

show_col(solarized_pal()(3))

show_col(solarized_pal("red")(4))