Skip to contents

Creates the base colors for a light or dark solarized theme. See https://ethanschoonover.com/solarized/. This function is a port of the CSS style example.

Usage

solarized_rebase(light = TRUE)

Arguments

light

If TRUE (the default), use the light theme; otherwise, use the dark theme.

Value

A named character vector of eight hex colors, named rebase03 to rebase3.