Skip to contents

Linetype palette based on the linepattern scheme in Stata. This palette supports up to 15 values.

Usage

stata_linetype_pal()

Value

A palette function. It takes the number of linetypes n and returns a character vector of n linetype specifications, and can be used as the palette argument of ggplot2::discrete_scale().

See also

Examples

stata_linetype_pal()(6)
#> [1] "solid" "84"    "23"    "F414"  "F4"    "8414" 

show_linetypes(stata_linetype_pal()(6))