Skip to contents

Theme with white panel and gray background.

Usage

theme_igray(base_size = 12, base_family = "")

Arguments

base_size

base font size, given in pts.

base_family

base font family

Value

A ggplot2 theme object (class theme).

Details

This theme inverts the colors of ggplot2::theme_gray(), with a white panel and a light gray area around it. This keeps a white background for the color scales, like ggplot2::theme_bw(). But by using a gray background, the plot is closer to the typographical color of the document, which is the motivation for using a gray panel in ggplot2::theme_gray(). This is similar to the style of plots in Stata and Tableau.

Examples

library("ggplot2")

p <- ggplot(mtcars) +
  geom_point(aes(x = wt, y = mpg, colour = factor(gear))) +
  facet_wrap(~am)
p + theme_igray()