Color palettes from LibreOffice Calc. This palette has 12 values.
Value
A palette function. It takes the number of colors n and returns a character vector of n
hex colors, and can be used as the palette argument of ggplot2::discrete_scale().
See also
Other color calc:
scale_fill_calc()