| excel_new_pal | R Documentation |
Color palettes used by current versions of Microsoft Office and Excel.
excel_new_pal(theme = "Office")
theme |
The name of the Office theme or color theme (not to be confused with ggplot2 themes) from which to derive the color palette. Available themes include: \Sexpr[results=rd]{ggthemes:::rd_optlist(names(ggthemes::ggthemes_data$excel$themes))} |
In 2023 Microsoft replaced the long-standing Office theme with a new
default and renamed the old one. The default here, "Office", is the
current palette; "Office 2013" is the palette Excel used from 2013
until 2022. The former ggthemes names "Office Theme" and
"Office 2007-2010" still work, and select "Office 2013" and
"Office 2007" respectively.
A palette function. It takes the number of colours n and returns a character vector of n
hex colours, and can be used as the palette argument of discrete_scale().
Other colour excel:
excel_pal(),
scale_colour_excel_new(),
scale_fill_excel()
library("scales")
for (i in names(ggthemes::ggthemes_data$excel$themes)) {
show_col(excel_new_pal(theme = i)(6))
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.