Skip to contents

The color palettes used in Microsoft Excel 97 (and up until Excel 2007). Use this for that classic ugly look and feel. For ironic purposes only. 3D bars and pies not included. Please never use this color palette.

Usage

excel_pal(line = TRUE)

Arguments

line

If TRUE, use the palette for lines and points. Otherwise, use the palette for area.

Value

A palette function. It takes the number of colors n and returns a character vector of n hex colors, and can be used as the palette argument of ggplot2::discrete_scale().

Examples

library("scales")

show_col(excel_pal()(7))

show_col(excel_pal(line = FALSE)(7))