Skip to contents

The standard three-color FiveThirtyEight palette for line plots comprises blue, red, and green.

Usage

fivethirtyeight_pal()

Value

A palette function. It takes the number of colors n and returns a character vector of n hex colors, and can be used as the palette argument of ggplot2::discrete_scale().

See also

Other color fivethirtyeight: scale_colour_fivethirtyeight()

Examples

library("scales")

show_col(fivethirtyeight_pal()(3))