The standard three-color FiveThirtyEight palette for line plots comprises blue, red, and green.
Value
A palette function. It takes the number of colors n and returns a character vector of n
hex colors, and can be used as the palette argument of ggplot2::discrete_scale().
See also
Other color fivethirtyeight:
scale_colour_fivethirtyeight()