View source: R/fivethirtyeight.R
| fivethirtyeight_pal | R Documentation |
The standard three-color FiveThirtyEight palette for line plots comprises blue, red, and green.
fivethirtyeight_pal()
A palette function. It takes the number of colours n and returns a character vector of n
hex colours, and can be used as the palette argument of discrete_scale().
Other colour fivethirtyeight:
scale_colour_fivethirtyeight()
library("scales")
show_col(fivethirtyeight_pal()(3))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.