The pander package ships with a default colorblind and printer-friendly color palette borrowed from https://jfly.iam.u-tokyo.ac.jp/color/.
Value
A character vector of n hex colors, recycled if n exceeds the number of colors available.
Unlike the other *_pal() functions, this is itself the palette function.
See also
Other color pander:
scale_color_pander()