| palette_pander | R Documentation |
The pander ships with a default colorblind and printer-friendly
color palette borrowed from https://jfly.iam.u-tokyo.ac.jp/color/.
palette_pander(n, random_order = FALSE)
n |
number of colors. This palette supports up to eight colors. |
random_order |
if the palette should be reordered randomly before rendering each plot to get colorful images |
A character vector of n hex colours, recycled if n exceeds the number of colours available.
Unlike the other *_pal() functions, this is itself the palette function.
Other colour pander:
scale_color_pander()
palette_pander(8)
# the same colors in a random order
palette_pander(8, random_order = TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.