| scale_shape_few | R Documentation |
scale_shape_few() maps discrete variables to up to five easily
discernible shapes. It is based on the shape palette suggested in
Few (2012).
scale_shape_few(...)
... |
Common |
A ggplot2 scale object.
Few, S. (2012) Show Me the Numbers: Designing Tables and Graphs to Enlighten, Analytics Press, p. 208.
scale_shape_few() for the shape palette that this
scale uses.
library("ggplot2")
ggplot(mtcars, aes(x = wt, y = mpg, shape = factor(gear))) +
geom_point(size = 3) +
scale_shape_few()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.