Qualitative color palette based on Ethan Schoonover's Solarized palette, https://ethanschoonover.com/solarized/. This palette supports up to seven values.
Value
A palette function. It takes the number of colors n and returns a character vector of n
hex colors, and can be used as the palette argument of ggplot2::discrete_scale().
Note
For a given starting color and number of colors in the palette, the other colors are the combination of colors that maximizes the total Euclidean distance between colors in Lab space.
See also
Other color solarized:
scale_fill_solarized()