Learn R Programming

ggthemes (version 3.0.0)

stat_fivenumber: Calculate components of a five-number summary

Description

The five number summary of a sample is the minimum, first quartile, median, third quartile, and maximum.

Usage

stat_fivenumber(mapping = NULL, data = NULL, geom = "boxplot", qs = c(0,
  0.25, 0.5, 0.75, 1), na.rm = FALSE, position = "identity",
  show.legend = NA, inherit.aes = TRUE, ...)

Arguments

mapping
The aesthetic mapping, usually constructed with aes or aes_string. Only needs to be set at the layer level if you are overriding the plot defaults.
data
A layer specific dataset - only needed if you want to override the plot defaults.
geom
The geometric object to use display the data
qs
Quantiles to use for the five number summary.
na.rm
If FALSE (the default), removes missing values with a warning. If TRUE silently removes missing values.
position
The position adjustment to use for overlapping points on this layer
show.legend
logical. Should this layer be included in the legends? NA, the default, includes if any aesthetics are mapped. FALSE never includes, and TRUE always includes.
inherit.aes
If FALSE, overrides the default aesthetics, rather than combining with them. This is most useful for helper functions that define both data and aesthetics and shouldn't inherit behaviour from the default plot specification, e.g.
...
other arguments passed on to layer. This can include aesthetics whose values you want to set, not map. See layer for more details.

Value

  • A data frame with additional columns:
  • widthwidth of boxplot
  • minminimum
  • lowerlower hinge, 25% quantile
  • middlemedian, 50% quantile
  • upperupper hinge, 75% quantile
  • maxmaximum

See Also

stat_boxplot