| stata_shape_pal | R Documentation |
Shape palette based on the symbol palette in Stata used in scheme s2mono. This palette supports up to 10 values.
stata_shape_pal(unicode = FALSE)
unicode |
If |
A palette function. It takes the number of shapes n and returns an integer vector of n
shape (pch) codes, and can be used as the palette argument of
discrete_scale().
Stata's ten plotting symbols all have a base pch equivalent, so this palette supports ten values on either branch and nothing is dropped: solid and hollow circle, diamond, square and triangle, plus the X and the plus sign.
See scale_shape_stata() for examples.
Other shapes stata:
scale_shape_stata()
stata_shape_pal()(10)
show_shapes(stata_shape_pal()(10))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.